# 4 "../../../circe2/src/lexer.mll"
 
open Parser
let unquote s =
  String.sub s 1 (String.length s - 2)

# 8 "lexer.ml"
let __ocaml_lex_tables = {
  Lexing.lex_base = 
   "\000\000\201\255\001\000\001\000\004\000\021\000\020\000\010\000\
    \022\000\002\000\027\000\005\000\028\000\024\000\029\000\029\000\
    \034\000\035\000\037\000\024\000\239\255\240\255\241\255\242\255\
    \243\255\244\255\245\255\246\255\247\255\248\255\249\255\250\255\
    \002\000\102\000\015\000\025\000\001\000\255\255\254\255\112\000\
    \124\000\134\000\156\000\166\000\251\255\041\000\036\000\044\000\
    \236\255\060\000\076\000\097\000\235\255\127\000\233\255\081\000\
    \075\000\234\255\089\000\089\000\084\000\100\000\088\000\232\255\
    \117\000\110\000\119\000\119\000\115\000\231\255\130\000\122\000\
    \117\000\230\255\119\000\130\000\133\000\127\000\229\255\137\000\
    \142\000\139\000\142\000\127\000\130\000\134\000\136\000\228\255\
    \227\255\137\000\132\000\134\000\226\255\149\000\143\000\224\255\
    \151\000\225\255\152\000\223\255\139\000\139\000\148\000\157\000\
    \147\000\165\000\155\000\222\255\164\000\221\255\152\000\170\000\
    \152\000\164\000\159\000\161\000\157\000\220\255\164\000\169\000\
    \219\255\165\000\164\000\217\255\218\255\216\255\161\000\164\000\
    \174\000\183\000\171\000\179\000\175\000\184\000\215\255\178\000\
    \187\000\177\000\173\000\179\000\181\000\214\255\212\255\191\000\
    \189\000\211\255\179\000\182\000\187\000\189\000\210\255\186\000\
    \209\255\192\000\193\000\206\000\213\255\193\000\190\000\195\000\
    \197\000\211\000\199\000\211\000\210\000\208\255\196\000\198\000\
    \207\255\203\000\218\000\208\000\216\000\206\255\207\000\203\000\
    \216\000\205\255\216\000\225\000\213\000\221\000\217\000\225\000\
    \204\255\215\000\217\000\221\000\203\255\230\000\215\000\228\000\
    \202\255";
  Lexing.lex_backtrk = 
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\003\000\018\000\017\000\255\255\255\255\255\255\255\255\
    \002\000\255\255\002\000\002\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255";
  Lexing.lex_default = 
   "\255\255\000\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \032\000\255\255\255\255\255\255\036\000\000\000\000\000\255\255\
    \255\255\255\255\255\255\255\255\000\000\255\255\255\255\255\255\
    \000\000\255\255\255\255\255\255\000\000\255\255\000\000\255\255\
    \255\255\000\000\255\255\255\255\255\255\255\255\255\255\000\000\
    \255\255\255\255\255\255\255\255\255\255\000\000\255\255\255\255\
    \255\255\000\000\255\255\255\255\255\255\255\255\000\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\000\000\
    \000\000\255\255\255\255\255\255\000\000\255\255\255\255\000\000\
    \255\255\000\000\255\255\000\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\000\000\255\255\000\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\000\000\255\255\255\255\
    \000\000\255\255\255\255\000\000\000\000\000\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\000\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\000\000\000\000\255\255\
    \255\255\000\000\255\255\255\255\255\255\255\255\000\000\255\255\
    \000\000\255\255\255\255\255\255\000\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\000\000\255\255\255\255\
    \000\000\255\255\255\255\255\255\255\255\000\000\255\255\255\255\
    \255\255\000\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\255\255\255\255\255\255\000\000\255\255\255\255\255\255\
    \000\000";
  Lexing.lex_trans = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\037\000\037\000\038\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \037\000\000\000\032\000\036\000\044\000\000\000\000\000\000\000\
    \029\000\025\000\020\000\035\000\027\000\034\000\000\000\031\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\000\000\000\000\028\000\021\000\024\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \033\000\033\000\033\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\030\000\000\000\026\000\000\000\000\000\
    \000\000\019\000\018\000\017\000\016\000\015\000\014\000\007\000\
    \013\000\012\000\189\000\153\000\011\000\010\000\009\000\185\000\
    \008\000\126\000\006\000\005\000\004\000\003\000\178\000\002\000\
    \170\000\158\000\118\000\023\000\122\000\022\000\137\000\136\000\
    \109\000\100\000\169\000\157\000\121\000\135\000\094\000\074\000\
    \059\000\081\000\050\000\045\000\046\000\047\000\049\000\093\000\
    \108\000\080\000\058\000\079\000\040\000\048\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \043\000\043\000\043\000\043\000\043\000\043\000\043\000\043\000\
    \043\000\043\000\053\000\039\000\040\000\040\000\040\000\040\000\
    \040\000\040\000\040\000\040\000\040\000\040\000\042\000\042\000\
    \042\000\042\000\042\000\042\000\042\000\042\000\042\000\042\000\
    \051\000\041\000\052\000\056\000\057\000\065\000\064\000\060\000\
    \061\000\062\000\063\000\039\000\042\000\042\000\042\000\042\000\
    \042\000\042\000\042\000\042\000\042\000\042\000\043\000\043\000\
    \043\000\043\000\043\000\043\000\043\000\043\000\043\000\043\000\
    \055\000\041\000\070\000\066\000\067\000\068\000\069\000\071\000\
    \072\000\073\000\075\000\076\000\077\000\078\000\089\000\088\000\
    \082\000\083\000\054\000\084\000\085\000\086\000\087\000\090\000\
    \091\000\092\000\098\000\096\000\097\000\099\000\101\000\102\000\
    \001\000\255\255\255\255\103\000\104\000\105\000\106\000\095\000\
    \107\000\110\000\111\000\112\000\113\000\114\000\115\000\116\000\
    \117\000\119\000\120\000\125\000\124\000\127\000\128\000\129\000\
    \130\000\131\000\132\000\133\000\123\000\134\000\145\000\142\000\
    \138\000\139\000\140\000\141\000\151\000\144\000\146\000\147\000\
    \148\000\143\000\149\000\150\000\152\000\154\000\155\000\156\000\
    \166\000\159\000\160\000\161\000\162\000\163\000\164\000\165\000\
    \167\000\168\000\174\000\171\000\172\000\173\000\175\000\176\000\
    \177\000\179\000\180\000\181\000\182\000\183\000\184\000\186\000\
    \187\000\188\000\190\000\191\000\192\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000";
  Lexing.lex_check = 
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\000\000\036\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\255\255\000\000\000\000\032\000\255\255\255\255\255\255\
    \000\000\000\000\000\000\000\000\000\000\000\000\255\255\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\255\255\255\255\000\000\000\000\000\000\034\000\
    \034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
    \034\000\035\000\035\000\035\000\035\000\035\000\035\000\035\000\
    \035\000\035\000\035\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\000\000\255\255\000\000\255\255\255\255\
    \255\255\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\002\000\007\000\000\000\000\000\000\000\003\000\
    \000\000\009\000\000\000\000\000\000\000\000\000\004\000\000\000\
    \005\000\006\000\011\000\000\000\010\000\000\000\008\000\008\000\
    \012\000\013\000\005\000\006\000\010\000\008\000\014\000\016\000\
    \017\000\015\000\018\000\019\000\045\000\046\000\018\000\014\000\
    \012\000\015\000\017\000\015\000\033\000\047\000\033\000\033\000\
    \033\000\033\000\033\000\033\000\033\000\033\000\033\000\033\000\
    \039\000\039\000\039\000\039\000\039\000\039\000\039\000\039\000\
    \039\000\039\000\049\000\033\000\040\000\040\000\040\000\040\000\
    \040\000\040\000\040\000\040\000\040\000\040\000\041\000\041\000\
    \041\000\041\000\041\000\041\000\041\000\041\000\041\000\041\000\
    \050\000\040\000\051\000\055\000\056\000\058\000\058\000\059\000\
    \060\000\061\000\062\000\033\000\042\000\042\000\042\000\042\000\
    \042\000\042\000\042\000\042\000\042\000\042\000\043\000\043\000\
    \043\000\043\000\043\000\043\000\043\000\043\000\043\000\043\000\
    \053\000\040\000\064\000\065\000\066\000\067\000\068\000\070\000\
    \071\000\072\000\074\000\075\000\076\000\077\000\079\000\080\000\
    \081\000\082\000\053\000\083\000\084\000\085\000\086\000\089\000\
    \090\000\091\000\093\000\094\000\096\000\098\000\100\000\101\000\
    \000\000\036\000\032\000\102\000\103\000\104\000\105\000\094\000\
    \106\000\108\000\110\000\111\000\112\000\113\000\114\000\115\000\
    \116\000\118\000\119\000\121\000\122\000\126\000\127\000\128\000\
    \129\000\130\000\131\000\132\000\122\000\133\000\135\000\136\000\
    \137\000\138\000\139\000\140\000\143\000\135\000\144\000\146\000\
    \147\000\135\000\148\000\149\000\151\000\153\000\154\000\155\000\
    \157\000\158\000\159\000\160\000\161\000\162\000\163\000\164\000\
    \166\000\167\000\169\000\170\000\171\000\172\000\174\000\175\000\
    \176\000\178\000\179\000\180\000\181\000\182\000\183\000\185\000\
    \186\000\187\000\189\000\190\000\191\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255";
  Lexing.lex_base_code = 
   "";
  Lexing.lex_backtrk_code = 
   "";
  Lexing.lex_default_code = 
   "";
  Lexing.lex_trans_code = 
   "";
  Lexing.lex_check_code = 
   "";
  Lexing.lex_code = 
   "";
}

let rec token lexbuf =
    __ocaml_lex_token_rec lexbuf 0
and __ocaml_lex_token_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 17 "../../../circe2/src/lexer.mll"
                 ( token lexbuf )
# 233 "lexer.ml"

  | 1 ->
# 19 "../../../circe2/src/lexer.mll"
                 ( token lexbuf )
# 238 "lexer.ml"

  | 2 ->
# 22 "../../../circe2/src/lexer.mll"
                 ( FLOAT (float_of_string (Lexing.lexeme lexbuf)) )
# 243 "lexer.ml"

  | 3 ->
# 24 "../../../circe2/src/lexer.mll"
                 ( INT (int_of_string (Lexing.lexeme lexbuf)) )
# 248 "lexer.ml"

  | 4 ->
# 26 "../../../circe2/src/lexer.mll"
                 ( STRING (unquote (Lexing.lexeme lexbuf)) )
# 253 "lexer.ml"

  | 5 ->
# 27 "../../../circe2/src/lexer.mll"
                 ( SLASH )
# 258 "lexer.ml"

  | 6 ->
# 28 "../../../circe2/src/lexer.mll"
                 ( LBRACKET )
# 263 "lexer.ml"

  | 7 ->
# 29 "../../../circe2/src/lexer.mll"
                 ( LPAREN )
# 268 "lexer.ml"

  | 8 ->
# 30 "../../../circe2/src/lexer.mll"
                 ( LANGLE )
# 273 "lexer.ml"

  | 9 ->
# 31 "../../../circe2/src/lexer.mll"
                 ( COMMA )
# 278 "lexer.ml"

  | 10 ->
# 32 "../../../circe2/src/lexer.mll"
                 ( RBRACKET )
# 283 "lexer.ml"

  | 11 ->
# 33 "../../../circe2/src/lexer.mll"
                 ( RPAREN )
# 288 "lexer.ml"

  | 12 ->
# 34 "../../../circe2/src/lexer.mll"
                 ( RANGLE )
# 293 "lexer.ml"

  | 13 ->
# 35 "../../../circe2/src/lexer.mll"
                 ( LBRACE )
# 298 "lexer.ml"

  | 14 ->
# 36 "../../../circe2/src/lexer.mll"
                 ( RBRACE )
# 303 "lexer.ml"

  | 15 ->
# 37 "../../../circe2/src/lexer.mll"
                 ( EQUALS )
# 308 "lexer.ml"

  | 16 ->
# 38 "../../../circe2/src/lexer.mll"
                 ( STAR )
# 313 "lexer.ml"

  | 17 ->
# 39 "../../../circe2/src/lexer.mll"
                 ( PLUS )
# 318 "lexer.ml"

  | 18 ->
# 40 "../../../circe2/src/lexer.mll"
                 ( MINUS )
# 323 "lexer.ml"

  | 19 ->
# 41 "../../../circe2/src/lexer.mll"
                 ( Ascii )
# 328 "lexer.ml"

  | 20 ->
# 42 "../../../circe2/src/lexer.mll"
                 ( Beta )
# 333 "lexer.ml"

  | 21 ->
# 43 "../../../circe2/src/lexer.mll"
                 ( Binary )
# 338 "lexer.ml"

  | 22 ->
# 44 "../../../circe2/src/lexer.mll"
                 ( Bins )
# 343 "lexer.ml"

  | 23 ->
# 45 "../../../circe2/src/lexer.mll"
                 ( Center )
# 348 "lexer.ml"

  | 24 ->
# 46 "../../../circe2/src/lexer.mll"
                 ( Columns )
# 353 "lexer.ml"

  | 25 ->
# 47 "../../../circe2/src/lexer.mll"
                 ( Comment )
# 358 "lexer.ml"

  | 26 ->
# 48 "../../../circe2/src/lexer.mll"
                 ( Design )
# 363 "lexer.ml"

  | 27 ->
# 49 "../../../circe2/src/lexer.mll"
                 ( Electron )
# 368 "lexer.ml"

  | 28 ->
# 50 "../../../circe2/src/lexer.mll"
                 ( Eta )
# 373 "lexer.ml"

  | 29 ->
# 51 "../../../circe2/src/lexer.mll"
                 ( Events )
# 378 "lexer.ml"

  | 30 ->
# 52 "../../../circe2/src/lexer.mll"
                 ( File )
# 383 "lexer.ml"

  | 31 ->
# 53 "../../../circe2/src/lexer.mll"
                 ( Fix )
# 388 "lexer.ml"

  | 32 ->
# 54 "../../../circe2/src/lexer.mll"
                 ( Free )
# 393 "lexer.ml"

  | 33 ->
# 55 "../../../circe2/src/lexer.mll"
                 ( Histogram )
# 398 "lexer.ml"

  | 34 ->
# 56 "../../../circe2/src/lexer.mll"
                 ( Id )
# 403 "lexer.ml"

  | 35 ->
# 57 "../../../circe2/src/lexer.mll"
                 ( Iterations )
# 408 "lexer.ml"

  | 36 ->
# 58 "../../../circe2/src/lexer.mll"
                 ( Lumi )
# 413 "lexer.ml"

  | 37 ->
# 59 "../../../circe2/src/lexer.mll"
                 ( Map )
# 418 "lexer.ml"

  | 38 ->
# 60 "../../../circe2/src/lexer.mll"
                 ( Max )
# 423 "lexer.ml"

  | 39 ->
# 61 "../../../circe2/src/lexer.mll"
                 ( Min )
# 428 "lexer.ml"

  | 40 ->
# 62 "../../../circe2/src/lexer.mll"
                 ( Notriangle )
# 433 "lexer.ml"

  | 41 ->
# 63 "../../../circe2/src/lexer.mll"
                 ( Photon )
# 438 "lexer.ml"

  | 42 ->
# 64 "../../../circe2/src/lexer.mll"
                 ( Photon )
# 443 "lexer.ml"

  | 43 ->
# 65 "../../../circe2/src/lexer.mll"
                 ( Pid )
# 448 "lexer.ml"

  | 44 ->
# 66 "../../../circe2/src/lexer.mll"
                 ( Pol )
# 453 "lexer.ml"

  | 45 ->
# 67 "../../../circe2/src/lexer.mll"
                 ( Positron )
# 458 "lexer.ml"

  | 46 ->
# 68 "../../../circe2/src/lexer.mll"
                 ( Power )
# 463 "lexer.ml"

  | 47 ->
# 69 "../../../circe2/src/lexer.mll"
                 ( Resonance )
# 468 "lexer.ml"

  | 48 ->
# 70 "../../../circe2/src/lexer.mll"
                 ( Roots )
# 473 "lexer.ml"

  | 49 ->
# 71 "../../../circe2/src/lexer.mll"
                 ( Scale )
# 478 "lexer.ml"

  | 50 ->
# 72 "../../../circe2/src/lexer.mll"
                 ( Smooth )
# 483 "lexer.ml"

  | 51 ->
# 73 "../../../circe2/src/lexer.mll"
                 ( Triangle )
# 488 "lexer.ml"

  | 52 ->
# 74 "../../../circe2/src/lexer.mll"
                 ( Unpol )
# 493 "lexer.ml"

  | 53 ->
# 75 "../../../circe2/src/lexer.mll"
                 ( Width )
# 498 "lexer.ml"

  | 54 ->
# 76 "../../../circe2/src/lexer.mll"
                 ( END )
# 503 "lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; 
      __ocaml_lex_token_rec lexbuf __ocaml_lex_state

;;

